@@ -1,5 +1,5 @@
 package App::TeleGramma::Plugin::Core::Stenographer;
-$App::TeleGramma::Plugin::Core::Stenographer::VERSION = '0.03';
+$App::TeleGramma::Plugin::Core::Stenographer::VERSION = '0.04';
 # ABSTRACT: TeleGramma plugin to log all text messages
 
 use Mojo::Base 'App::TeleGramma::Plugin::Base';
@@ -46,7 +46,10 @@ sub log_message {
   return PLUGIN_NO_RESPONSE unless $msg->text;  # don't try to deal with anything but text
 
   my $fh = $self->log_fh_for_message($msg);
-  my $text = sprintf("%-26s %s: %s\n", scalar localtime, $msg->chat->username, $msg->text);
+  my $username = 'unknown';
+  $username = $msg->from->username if ($msg->from);
+
+  my $text = sprintf("%-26s %s: %s\n", scalar localtime, $username, $msg->text);
   print $fh $text;
   close $fh;
 
@@ -67,7 +70,7 @@ App::TeleGramma::Plugin::Core::Stenographer - TeleGramma plugin to log all text
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
